==> S1Tiling-0.2.0rc5.tar.gz: S1Tiling-0.2.0rc5/s1tiling/__meta__.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# =========================================================================
#   Copyright 2017-2021 (c) CESBIO. All rights reserved.
#
#   This file is part of S1Tiling project
#       https://gitlab.orfeo-toolbox.org/s1-tiling/s1tiling
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# =========================================================================
#
# Authors: Thierry KOLECK (CNES)
#          Luc HERMITTE (CS Group)
#
# =========================================================================

"""
Holds project meta-information for setup.py
"""

from __future__ import unicode_literals

__title__ = "S1Tiling"
__description__ = "On demand Ortho-rectification of Sentinel-1 data on Sentinel-2 grid."
__version__ = "0.2.0rc5"
__author__ = "Thierry KOLECK"
__author_email__ = "Thierry.Koleck@cnes.fr"
__url__ = "https://gitlab.orfeo-toolbox.org/s1-tiling/s1tiling"
__license__ = "Apache 2.0"
__copyright__ = "Copyright 2017-2021, CESBIO"

==> S1Tiling-0.3.0.tar.gz: S1Tiling-0.3.0/s1tiling/__meta__.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# =========================================================================
#   Copyright 2017-2021 (c) CNES. All rights reserved.
#
#   This file is part of S1Tiling project
#       https://gitlab.orfeo-toolbox.org/s1-tiling/s1tiling
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# =========================================================================
#
# Authors: Thierry KOLECK (CNES)
#          Luc HERMITTE (CS Group)
#
# =========================================================================

"""
Holds project meta-information for setup.py
"""

from __future__ import unicode_literals

__title__ = "S1Tiling"
__description__ = "On demand Ortho-rectification of Sentinel-1 data on Sentinel-2 grid."
__version__ = "0.3.0"
__author__ = "Thierry KOLECK"
__author_email__ = "Thierry.Koleck@cnes.fr"
__url__ = "https://gitlab.orfeo-toolbox.org/s1-tiling/s1tiling"
__license__ = "Apache 2.0"
__copyright__ = "2017-2021, CNES"
